package eu.siacs.conversations.services;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.preference.PreferenceManager;
import android.support.v4.content.ContextCompat;
import android.util.Log;

import java.util.Calendar;

import eu.siacs.conversations.Config;
import eu.siacs.conversations.utils.Compatibility;

public class EventReceiver extends BroadcastReceiver {

    public static final String SETTING_ENABLED_ACCOUNTS = "enabled_accounts";
    public static final String EXTRA_NEEDS_FOREGROUND_SERVICE = "needs_foreground_service";
	private static Boolean isAlarmStarted = false;

    @Override
    public void onReceive(final Context context, final Intent originalIntent) {
		if (originalIntent.getAction().equals("android.intent.action.BOOT_COMPLETED") || !isAlarmStarted) {
			PendingIntent alarmIntent = PendingIntent.getService(context, 0, new Intent(context, BackupService.class), 0);

			Calendar calendar = Calendar.getInstance();
			calendar.setTimeInMillis(System.currentTimeMillis());
			calendar.set(Calendar.HOUR_OF_DAY, 4);
			calendar.set(Calendar.MINUTE, 0);
			calendar.set(Calendar.SECOND, 0);

			// With setInexactRepeating(), you have to use one of the AlarmManager interval
			// constants--in this case, AlarmManager.INTERVAL_DAY.
			AlarmManager alarmMgr = (AlarmManager)(context.getSystemService(Context.ALARM_SERVICE));
			alarmMgr.setInexactRepeating(AlarmManager.RTC_WAKEUP, calendar.getTimeInMillis(), AlarmManager.INTERVAL_DAY, alarmIntent);

			Log.d(Config.LOGTAG, "BackupService: alarm started for next run: "+calendar.getTime().toString());
			isAlarmStarted = true;
		}
        final Intent intentForService = new Intent(context, XmppConnectionService.class);
        if (originalIntent.getAction() != null) {
            intentForService.setAction(originalIntent.getAction());
        } else {
            intentForService.setAction("other");
        }
        final String action = originalIntent.getAction();
        if (action.equals("ui") || hasEnabledAccounts(context)) {
            try {
                if (Compatibility.runsAndTargetsTwentySix(context)) {
                    intentForService.putExtra(EXTRA_NEEDS_FOREGROUND_SERVICE, true);
                    ContextCompat.startForegroundService(context, intentForService);
                } else {
                    context.startService(intentForService);
                }
            } catch (RuntimeException e) {
                Log.d(Config.LOGTAG, "EventReceiver was unable to start service");
            }
        } else {
            Log.d(Config.LOGTAG, "EventReceiver ignored action " + intentForService.getAction());
        }
    }

    public static boolean hasEnabledAccounts(final Context context) {
        return PreferenceManager.getDefaultSharedPreferences(context).getBoolean(SETTING_ENABLED_ACCOUNTS, true);
    }

}
